@@ -10,22 +10,19 @@ use {
     num_derive::{FromPrimitive, ToPrimitive},
     serde_derive::{Deserialize, Serialize},
     solana_metrics::inc_new_counter_info,
+    solana_program_runtime::invoke_context::InvokeContext,
     solana_sdk::{
         decode_error::DecodeError,
         feature_set,
         hash::Hash,
         instruction::{AccountMeta, Instruction, InstructionError},
-        keyed_account::{
-            check_sysvar_keyed_account, from_keyed_account, get_signers, keyed_account_at_index,
-            KeyedAccount,
-        },
-        process_instruction::InvokeContext,
+        keyed_account::{from_keyed_account, get_signers, keyed_account_at_index, KeyedAccount},
         program_utils::limited_deserialize,
         pubkey::Pubkey,
         system_instruction,
-        sysvar::{self, clock::Clock, rent::Rent, slot_hashes::SlotHashes},
+        sysvar::{self, clock::Clock, slot_hashes::SlotHashes},
     },
-    std::{collections::HashSet, sync::Arc},
+    std::collections::HashSet,
     thiserror::Error,
 };
 
@@ -49,6 +46,37 @@ pub enum VoteError {
 
     #[error("authorized voter has already been changed this epoch")]
     TooSoonToReauthorize,
+
+    // TODO: figure out how to migrate these new errors
+    #[error("Old state had vote which should not have been popped off by vote in new state")]
+    LockoutConflict,
+
+    #[error("Proposed state had earlier slot which should have been popped off by later vote")]
+    NewVoteStateLockoutMismatch,
+
+    #[error("Vote slots are not ordered")]
+    SlotsNotOrdered,
+
+    #[error("Confirmations are not ordered")]
+    ConfirmationsNotOrdered,
+
+    #[error("Zero confirmations")]
+    ZeroConfirmations,
+
+    #[error("Confirmation exceeds limit")]
+    ConfirmationTooLarge,
+
+    #[error("Root rolled back")]
+    RootRollBack,
+
+    #[error("Confirmations for same vote were smaller in new proposed state")]
+    ConfirmationRollBack,
+
+    #[error("New state contained a vote slot smaller than the root")]
+    SlotSmallerThanRoot,
+
+    #[error("New state contained too many votes")]
+    TooManyVotes,
 }
 
 impl<E> DecodeError<E> for VoteError {
@@ -62,59 +90,59 @@ pub enum VoteInstruction {
     /// Initialize a vote account
     ///
     /// # Account references
-    ///   0. [WRITE] Uninitialized vote account
-    ///   1. [] Rent sysvar
-    ///   2. [] Clock sysvar
-    ///   3. [SIGNER] New validator identity (node_pubkey)
+    ///   0. `[WRITE]` Uninitialized vote account
+    ///   1. `[]` Rent sysvar
+    ///   2. `[]` Clock sysvar
+    ///   3. `[SIGNER]` New validator identity (node_pubkey)
     InitializeAccount(VoteInit),
 
     /// Authorize a key to send votes or issue a withdrawal
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to be updated with the Pubkey for authorization
-    ///   1. [] Clock sysvar
-    ///   2. [SIGNER] Vote or withdraw authority
+    ///   0. `[WRITE]` Vote account to be updated with the Pubkey for authorization
+    ///   1. `[]` Clock sysvar
+    ///   2. `[SIGNER]` Vote or withdraw authority
     Authorize(Pubkey, VoteAuthorize),
 
     /// A Vote instruction with recent votes
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to vote with
-    ///   1. [] Slot hashes sysvar
-    ///   2. [] Clock sysvar
-    ///   3. [SIGNER] Vote authority
+    ///   0. `[WRITE]` Vote account to vote with
+    ///   1. `[]` Slot hashes sysvar
+    ///   2. `[]` Clock sysvar
+    ///   3. `[SIGNER]` Vote authority
     Vote(Vote),
 
     /// Withdraw some amount of funds
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to withdraw from
-    ///   1. [WRITE] Recipient account
-    ///   2. [SIGNER] Withdraw authority
+    ///   0. `[WRITE]` Vote account to withdraw from
+    ///   1. `[WRITE]` Recipient account
+    ///   2. `[SIGNER]` Withdraw authority
     Withdraw(u64),
 
     /// Update the vote account's validator identity (node_pubkey)
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to be updated with the given authority public key
-    ///   1. [SIGNER] New validator identity (node_pubkey)
-    ///   2. [SIGNER] Withdraw authority
+    ///   0. `[WRITE]` Vote account to be updated with the given authority public key
+    ///   1. `[SIGNER]` New validator identity (node_pubkey)
+    ///   2. `[SIGNER]` Withdraw authority
     UpdateValidatorIdentity,
 
     /// Update the commission for the vote account
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to be updated
-    ///   1. [SIGNER] Withdraw authority
+    ///   0. `[WRITE]` Vote account to be updated
+    ///   1. `[SIGNER]` Withdraw authority
     UpdateCommission(u8),
 
     /// A Vote instruction with recent votes
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to vote with
-    ///   1. [] Slot hashes sysvar
-    ///   2. [] Clock sysvar
-    ///   3. [SIGNER] Vote authority
+    ///   0. `[WRITE]` Vote account to vote with
+    ///   1. `[]` Slot hashes sysvar
+    ///   2. `[]` Clock sysvar
+    ///   3. `[SIGNER]` Vote authority
     VoteSwitch(Vote, Hash),
 
     /// Authorize a key to send votes or issue a withdrawal
@@ -123,10 +151,10 @@ pub enum VoteInstruction {
     /// or withdraw authority must also be a signer.
     ///
     /// # Account references
-    ///   0. [WRITE] Vote account to be updated with the Pubkey for authorization
-    ///   1. [] Clock sysvar
-    ///   2. [SIGNER] Vote or withdraw authority
-    ///   3. [SIGNER] New vote or withdraw authority
+    ///   0. `[WRITE]` Vote account to be updated with the Pubkey for authorization
+    ///   1. `[]` Clock sysvar
+    ///   2. `[SIGNER]` Vote or withdraw authority
+    ///   3. `[SIGNER]` New vote or withdraw authority
     AuthorizeChecked(VoteAuthorize),
 }
 
@@ -302,8 +330,9 @@ pub fn withdraw(
 
 fn verify_rent_exemption(
     keyed_account: &KeyedAccount,
-    rent: &Rent,
+    rent_sysvar_account: &KeyedAccount,
 ) -> Result<(), InstructionError> {
+    let rent: sysvar::rent::Rent = from_keyed_account(rent_sysvar_account)?;
     if !rent.is_exempt(keyed_account.lamports()?, keyed_account.data_len()?) {
         Err(InstructionError::InsufficientFunds)
     } else {
@@ -311,82 +340,51 @@ fn verify_rent_exemption(
     }
 }
 
-/// These methods facilitate a transition from fetching sysvars from keyed
-/// accounts to fetching from the sysvar cache without breaking consensus. In
-/// order to keep consistent behavior, they continue to enforce the same checks
-/// as `solana_sdk::keyed_account::from_keyed_account` despite dynamically
-/// loading them instead of deserializing from account data.
-mod get_sysvar_with_keyed_account_check {
-    use super::*;
-
-    pub fn clock(
-        keyed_account: &KeyedAccount,
-        invoke_context: &dyn InvokeContext,
-    ) -> Result<Arc<Clock>, InstructionError> {
-        check_sysvar_keyed_account::<Clock>(keyed_account)?;
-        invoke_context.get_sysvar_cache().get_clock()
-    }
-
-    pub fn rent(
-        keyed_account: &KeyedAccount,
-        invoke_context: &dyn InvokeContext,
-    ) -> Result<Arc<Rent>, InstructionError> {
-        check_sysvar_keyed_account::<Rent>(keyed_account)?;
-        invoke_context.get_sysvar_cache().get_rent()
-    }
-
-    pub fn slot_hashes(
-        keyed_account: &KeyedAccount,
-        invoke_context: &dyn InvokeContext,
-    ) -> Result<Arc<SlotHashes>, InstructionError> {
-        check_sysvar_keyed_account::<SlotHashes>(keyed_account)?;
-        invoke_context.get_sysvar_cache().get_slot_hashes()
-    }
-}
-
 pub fn process_instruction(
-    _program_id: &Pubkey,
+    first_instruction_account: usize,
     data: &[u8],
-    invoke_context: &mut dyn InvokeContext,
+    invoke_context: &mut InvokeContext,
 ) -> Result<(), InstructionError> {
     let keyed_accounts = invoke_context.get_keyed_accounts()?;
 
     trace!("process_instruction: {:?}", data);
     trace!("keyed_accounts: {:?}", keyed_accounts);
 
-    let signers: HashSet<Pubkey> = get_signers(keyed_accounts);
-
-    let me = &mut keyed_account_at_index(keyed_accounts, 0)?;
-
-    if invoke_context.is_feature_active(&feature_set::check_program_owner::id())
-        && me.owner()? != id()
-    {
+    let me = &mut keyed_account_at_index(keyed_accounts, first_instruction_account)?;
+    if me.owner()? != id() {
         return Err(InstructionError::InvalidAccountOwner);
     }
 
+    let signers: HashSet<Pubkey> = get_signers(&keyed_accounts[first_instruction_account..]);
     match limited_deserialize(data)? {
         VoteInstruction::InitializeAccount(vote_init) => {
-            let rent = get_sysvar_with_keyed_account_check::rent(
-                keyed_account_at_index(keyed_accounts, 1)?,
-                invoke_context,
+            verify_rent_exemption(
+                me,
+                keyed_account_at_index(keyed_accounts, first_instruction_account + 1)?,
             )?;
-            verify_rent_exemption(me, &rent)?;
-            let clock = get_sysvar_with_keyed_account_check::clock(
-                keyed_account_at_index(keyed_accounts, 2)?,
-                invoke_context,
-            )?;
-            vote_state::initialize_account(me, &vote_init, &signers, &clock)
-        }
-        VoteInstruction::Authorize(voter_pubkey, vote_authorize) => {
-            let clock = get_sysvar_with_keyed_account_check::clock(
-                keyed_account_at_index(keyed_accounts, 1)?,
-                invoke_context,
-            )?;
-            vote_state::authorize(me, &voter_pubkey, vote_authorize, &signers, &clock)
+            vote_state::initialize_account(
+                me,
+                &vote_init,
+                &signers,
+                &from_keyed_account::<Clock>(keyed_account_at_index(
+                    keyed_accounts,
+                    first_instruction_account + 2,
+                )?)?,
+            )
         }
+        VoteInstruction::Authorize(voter_pubkey, vote_authorize) => vote_state::authorize(
+            me,
+            &voter_pubkey,
+            vote_authorize,
+            &signers,
+            &from_keyed_account::<Clock>(keyed_account_at_index(
+                keyed_accounts,
+                first_instruction_account + 1,
+            )?)?,
+        ),
         VoteInstruction::UpdateValidatorIdentity => vote_state::update_validator_identity(
             me,
-            keyed_account_at_index(keyed_accounts, 1)?.unsigned_key(),
+            keyed_account_at_index(keyed_accounts, first_instruction_account + 1)?.unsigned_key(),
             &signers,
         ),
         VoteInstruction::UpdateCommission(commission) => {
@@ -394,53 +392,50 @@ pub fn process_instruction(
         }
         VoteInstruction::Vote(vote) | VoteInstruction::VoteSwitch(vote, _) => {
             inc_new_counter_info!("vote-native", 1);
-            let slot_hashes = get_sysvar_with_keyed_account_check::slot_hashes(
-                keyed_account_at_index(keyed_accounts, 1)?,
-                invoke_context,
-            )?;
-            let clock = get_sysvar_with_keyed_account_check::clock(
-                keyed_account_at_index(keyed_accounts, 2)?,
-                invoke_context,
-            )?;
-            vote_state::process_vote(me, &slot_hashes, &clock, &vote, &signers)
-        }
-        VoteInstruction::Withdraw(lamports) => {
-            let to = keyed_account_at_index(keyed_accounts, 1)?;
-            let rent_sysvar = if invoke_context
-                .is_feature_active(&feature_set::reject_non_rent_exempt_vote_withdraws::id())
-            {
-                Some(invoke_context.get_sysvar_cache().get_rent()?)
-            } else {
-                None
-            };
-            let clock_if_feature_active = if invoke_context.is_feature_active(
-                &feature_set::reject_vote_account_close_unless_zero_credit_epoch::id(),
-            ) {
-                Some(invoke_context.get_sysvar_cache().get_clock()?)
-            } else {
-                None
-            };
-            vote_state::withdraw(
+            vote_state::process_vote(
                 me,
-                lamports,
-                to,
+                &from_keyed_account::<SlotHashes>(keyed_account_at_index(
+                    keyed_accounts,
+                    first_instruction_account + 1,
+                )?)?,
+                &from_keyed_account::<Clock>(keyed_account_at_index(
+                    keyed_accounts,
+                    first_instruction_account + 2,
+                )?)?,
+                &vote,
                 &signers,
-                rent_sysvar.as_deref(),
-                clock_if_feature_active.as_deref(),
             )
         }
-        VoteInstruction::AuthorizeChecked(vote_authorize) => {
-            if invoke_context.is_feature_active(&feature_set::vote_stake_checked_instructions::id())
+        VoteInstruction::Withdraw(lamports) => {
+            let to = keyed_account_at_index(keyed_accounts, first_instruction_account + 1)?;
+            let rent_sysvar = if invoke_context
+                .feature_set
+                .is_active(&feature_set::reject_non_rent_exempt_vote_withdraws::id())
             {
-                let voter_pubkey = &keyed_account_at_index(keyed_accounts, 3)?
-                    .signer_key()
-                    .ok_or(InstructionError::MissingRequiredSignature)?;
+                Some(invoke_context.get_sysvar(&sysvar::rent::id())?)
+            } else {
+                None
+            };
+            vote_state::withdraw(me, lamports, to, &signers, rent_sysvar)
+        }
+        VoteInstruction::AuthorizeChecked(vote_authorize) => {
+            if invoke_context
+                .feature_set
+                .is_active(&feature_set::vote_stake_checked_instructions::id())
+            {
+                let voter_pubkey =
+                    &keyed_account_at_index(keyed_accounts, first_instruction_account + 3)?
+                        .signer_key()
+                        .ok_or(InstructionError::MissingRequiredSignature)?;
                 vote_state::authorize(
                     me,
                     voter_pubkey,
                     vote_authorize,
                     &signers,
-                    &from_keyed_account::<Clock>(keyed_account_at_index(keyed_accounts, 1)?)?,
+                    &from_keyed_account::<Clock>(keyed_account_at_index(
+                        keyed_accounts,
+                        first_instruction_account + 1,
+                    )?)?,
                 )
             } else {
                 Err(InstructionError::InvalidInstructionData)
@@ -454,39 +449,37 @@ mod tests {
     use {
         super::*,
         bincode::serialize,
+        solana_program_runtime::invoke_context::mock_process_instruction,
         solana_sdk::{
             account::{self, Account, AccountSharedData},
-            process_instruction::MockInvokeContext,
             rent::Rent,
-            sysvar_cache::SysvarCache,
         },
-        std::{borrow::Cow, cell::RefCell, str::FromStr},
+        std::{cell::RefCell, rc::Rc, str::FromStr},
     };
 
-    fn create_default_account() -> RefCell<AccountSharedData> {
-        RefCell::new(AccountSharedData::default())
+    fn create_default_account() -> Rc<RefCell<AccountSharedData>> {
+        AccountSharedData::new_ref(0, 0, &Pubkey::new_unique())
     }
 
-    // these are for 100% coverage in this file
-    #[test]
-    fn test_vote_process_instruction_decode_bail() {
-        assert_eq!(
-            super::process_instruction(
-                &Pubkey::default(),
-                &[],
-                &mut MockInvokeContext::new(vec![])
-            ),
-            Err(InstructionError::NotEnoughAccountKeys),
-        );
+    fn process_instruction(
+        instruction_data: &[u8],
+        keyed_accounts: &[(bool, bool, Pubkey, Rc<RefCell<AccountSharedData>>)],
+    ) -> Result<(), InstructionError> {
+        mock_process_instruction(
+            &id(),
+            Vec::new(),
+            instruction_data,
+            keyed_accounts,
+            super::process_instruction,
+        )
     }
 
-    #[allow(clippy::same_item_push)]
-    fn process_instruction(instruction: &Instruction) -> Result<(), InstructionError> {
+    fn process_instruction_as_one_arg(instruction: &Instruction) -> Result<(), InstructionError> {
         let mut accounts: Vec<_> = instruction
             .accounts
             .iter()
             .map(|meta| {
-                RefCell::new(if sysvar::clock::check_id(&meta.pubkey) {
+                Rc::new(RefCell::new(if sysvar::clock::check_id(&meta.pubkey) {
                     account::create_account_shared_data_for_test(&Clock::default())
                 } else if sysvar::slot_hashes::check_id(&meta.pubkey) {
                     account::create_account_shared_data_for_test(&SlotHashes::default())
@@ -502,40 +495,51 @@ mod tests {
                         owner: id(),
                         ..Account::default()
                     })
-                })
+                }))
             })
             .collect();
-
+        #[allow(clippy::same_item_push)]
         for _ in 0..instruction.accounts.len() {
-            accounts.push(RefCell::new(AccountSharedData::default()));
-        }
-        {
-            let keyed_accounts: Vec<_> = instruction
-                .accounts
-                .iter()
-                .zip(accounts.iter())
-                .map(|(meta, account)| KeyedAccount::new(&meta.pubkey, meta.is_signer, account))
-                .collect();
-            let mut invoke_context = MockInvokeContext::new(keyed_accounts);
-            let mut sysvar_cache = SysvarCache::default();
-            sysvar_cache.set_rent(Rent::free());
-            sysvar_cache.set_clock(Clock::default());
-            sysvar_cache.set_slot_hashes(SlotHashes::default());
-            invoke_context.sysvar_cache = Cow::Owned(sysvar_cache);
-            super::process_instruction(&Pubkey::default(), &instruction.data, &mut invoke_context)
+            accounts.push(AccountSharedData::new_ref(0, 0, &Pubkey::new_unique()));
         }
+        let keyed_accounts: Vec<_> = instruction
+            .accounts
+            .iter()
+            .zip(accounts.into_iter())
+            .map(|(meta, account)| (meta.is_signer, meta.is_writable, meta.pubkey, account))
+            .collect();
+
+        let rent = Rent::default();
+        let rent_sysvar = (sysvar::rent::id(), bincode::serialize(&rent).unwrap());
+        solana_program_runtime::invoke_context::mock_process_instruction_with_sysvars(
+            &id(),
+            Vec::new(),
+            &instruction.data,
+            &keyed_accounts,
+            &[rent_sysvar],
+            super::process_instruction,
+        )
     }
 
     fn invalid_vote_state_pubkey() -> Pubkey {
         Pubkey::from_str("BadVote111111111111111111111111111111111111").unwrap()
     }
 
+    // these are for 100% coverage in this file
+    #[test]
+    fn test_vote_process_instruction_decode_bail() {
+        assert_eq!(
+            process_instruction(&[], &[]),
+            Err(InstructionError::NotEnoughAccountKeys),
+        );
+    }
+
     #[test]
     fn test_spoofed_vote() {
         assert_eq!(
-            process_instruction(&vote(
+            process_instruction_as_one_arg(&vote(
                 &invalid_vote_state_pubkey(),
-                &Pubkey::default(),
+                &Pubkey::new_unique(),
                 Vote::default(),
             )),
             Err(InstructionError::InvalidAccountOwner),
@@ -546,64 +550,64 @@ mod tests {
     fn test_vote_process_instruction() {
         solana_logger::setup();
         let instructions = create_account(
-            &Pubkey::default(),
-            &Pubkey::default(),
+            &Pubkey::new_unique(),
+            &Pubkey::new_unique(),
             &VoteInit::default(),
             100,
         );
         assert_eq!(
-            process_instruction(&instructions[1]),
+            process_instruction_as_one_arg(&instructions[1]),
             Err(InstructionError::InvalidAccountData),
         );
         assert_eq!(
-            process_instruction(&vote(
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&vote(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
                 Vote::default(),
             )),
             Err(InstructionError::InvalidAccountData),
         );
         assert_eq!(
-            process_instruction(&vote_switch(
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&vote_switch(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
                 Vote::default(),
                 Hash::default(),
             )),
             Err(InstructionError::InvalidAccountData),
         );
         assert_eq!(
-            process_instruction(&authorize(
-                &Pubkey::default(),
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&authorize(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
                 VoteAuthorize::Voter,
             )),
             Err(InstructionError::InvalidAccountData),
         );
         assert_eq!(
-            process_instruction(&update_validator_identity(
-                &Pubkey::default(),
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&update_validator_identity(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
             )),
             Err(InstructionError::InvalidAccountData),
         );
         assert_eq!(
-            process_instruction(&update_commission(
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&update_commission(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
                 0,
             )),
             Err(InstructionError::InvalidAccountData),
         );
 
         assert_eq!(
-            process_instruction(&withdraw(
-                &Pubkey::default(),
-                &Pubkey::default(),
+            process_instruction_as_one_arg(&withdraw(
+                &Pubkey::new_unique(),
+                &Pubkey::new_unique(),
                 0,
-                &Pubkey::default()
+                &Pubkey::new_unique()
             )),
             Err(InstructionError::InvalidAccountData),
         );
@@ -624,7 +628,7 @@ mod tests {
         );
         instruction.accounts = instruction.accounts[0..2].to_vec();
         assert_eq!(
-            process_instruction(&instruction),
+            process_instruction_as_one_arg(&instruction),
             Err(InstructionError::NotEnoughAccountKeys),
         );
 
@@ -636,7 +640,7 @@ mod tests {
         );
         instruction.accounts = instruction.accounts[0..2].to_vec();
         assert_eq!(
-            process_instruction(&instruction),
+            process_instruction_as_one_arg(&instruction),
             Err(InstructionError::NotEnoughAccountKeys),
         );
 
@@ -649,7 +653,7 @@ mod tests {
         );
         instruction.accounts[3] = AccountMeta::new_readonly(new_authorized_pubkey, false);
         assert_eq!(
-            process_instruction(&instruction),
+            process_instruction_as_one_arg(&instruction),
             Err(InstructionError::MissingRequiredSignature),
         );
 
@@ -661,48 +665,40 @@ mod tests {
         );
         instruction.accounts[3] = AccountMeta::new_readonly(new_authorized_pubkey, false);
         assert_eq!(
-            process_instruction(&instruction),
+            process_instruction_as_one_arg(&instruction),
             Err(InstructionError::MissingRequiredSignature),
         );
 
         // Test with new_authorized_pubkey signer
         let vote_account = AccountSharedData::new_ref(100, VoteState::size_of(), &id());
         let clock_address = sysvar::clock::id();
-        let clock_account = RefCell::new(account::create_account_shared_data_for_test(
+        let clock_account = Rc::new(RefCell::new(account::create_account_shared_data_for_test(
             &Clock::default(),
-        ));
+        )));
         let default_authorized_pubkey = Pubkey::default();
         let authorized_account = create_default_account();
         let new_authorized_account = create_default_account();
-        let keyed_accounts = vec![
-            KeyedAccount::new(&vote_pubkey, false, &vote_account),
-            KeyedAccount::new(&clock_address, false, &clock_account),
-            KeyedAccount::new(&default_authorized_pubkey, true, &authorized_account),
-            KeyedAccount::new(&new_authorized_pubkey, true, &new_authorized_account),
+        let keyed_accounts = [
+            (false, false, vote_pubkey, vote_account),
+            (false, false, clock_address, clock_account),
+            (true, false, default_authorized_pubkey, authorized_account),
+            (true, false, new_authorized_pubkey, new_authorized_account),
         ];
         assert_eq!(
-            super::process_instruction(
-                &Pubkey::default(),
+            process_instruction(
                 &serialize(&VoteInstruction::AuthorizeChecked(VoteAuthorize::Voter)).unwrap(),
-                &mut MockInvokeContext::new(keyed_accounts)
+                &keyed_accounts,
             ),
             Ok(())
         );
 
-        let keyed_accounts = vec![
-            KeyedAccount::new(&vote_pubkey, false, &vote_account),
-            KeyedAccount::new(&clock_address, false, &clock_account),
-            KeyedAccount::new(&default_authorized_pubkey, true, &authorized_account),
-            KeyedAccount::new(&new_authorized_pubkey, true, &new_authorized_account),
-        ];
         assert_eq!(
-            super::process_instruction(
-                &Pubkey::default(),
+            process_instruction(
                 &serialize(&VoteInstruction::AuthorizeChecked(
                     VoteAuthorize::Withdrawer
                 ))
                 .unwrap(),
-                &mut MockInvokeContext::new(keyed_accounts)
+                &keyed_accounts,
             ),
             Ok(())
         );
@@ -710,7 +706,7 @@ mod tests {
 
     #[test]
     fn test_minimum_balance() {
-        let rent = Rent::default();
+        let rent = solana_sdk::rent::Rent::default();
         let minimum_balance = rent.minimum_balance(VoteState::size_of());
         // golden, may need updating when vote_state grows
         assert!(minimum_balance as f64 / 10f64.powf(9.0) < 0.04)
